import { Request, Response } from 'express';
import { prisma } from '../../../lib/prisma';
import { Prisma } from '@prisma/client';

export async function listArticles(req: Request, res: Response) {
  try {
    const { page = 1, categoryId, cityId } = req.query;
    const perPage = 6;

    // Преобразование и проверка параметров
    const catId = Number(categoryId);
    const citId = Number(cityId);

    // Проверка и преобразование параметров
    const where: Prisma.ArticleWhereInput = {
      ...(categoryId && !Number.isNaN(catId) && catId !== 0 && { categoryId: catId }),
      ...(cityId && !Number.isNaN(citId) && citId !== 0 && { cityId: citId }),
    };

    // Рассчитываем пропуск записей для пагинации
    const skip = (Number(page) - 1) * perPage;

    // Выполняем два параллельных запроса: получение статей и подсчёт общего количества
    const [articles, total] = await Promise.all([
      prisma.article.findMany({
        where,
        include: {
          author: {
            select: {
              id: true,
              displayName: true,
              avatarUrl: true,
              email: true
            },
          },
        },
        skip,
        take: perPage,
        orderBy: { publishedAt: 'desc' },
      }),
      prisma.article.count({ where }),
    ]);

    // Формируем ответ
    res.json({
      articles,
      totalPages: Math.ceil(total / perPage),
      currentPage: Number(page),
    });
  } catch (error) {
    // Логируем ошибку и отправляем ответ с кодом 500
    console.error('Error during articles list:', error);
    res.status(500).json({ error: 'Server error' });
  }
}
